==> pyqt-windows-buttons-widget-0.0.15.tar.gz: pyqt-windows-buttons-widget-0.0.15/pyqt_windows_buttons_widget/windowsButtonsWidget.py <==
from PyQt5.QtGui import QPalette
from PyQt5.QtWidgets import QWidget
from pyqt_titlebar_buttons_widget import TitlebarButtonsWidget


class WindowsButtonsWidget(TitlebarButtonsWidget):
    def __init__(self, base_widget: QWidget, hint: list = ['min', 'max', 'close']):
        super().__init__(base_widget, hint)
        self.__initUi()

    def __initUi(self):
        self._minimizeBtn.setText('🗕')
        self._maximizeBtn.setText('🗖')
        self._closeBtn.setText('🗙')

        self.__styleInit()

        self.__window = self._base_widget.window()
        self.__window.installEventFilter(self)

    def __styleInit(self):
        # fill the button's background with color
        background_color = self._base_widget.palette().color(QPalette.Base).name()
        for btn in self._btn_dict.values():
            btn.setBackground(background_color)

        close_button_style = self._closeBtn.styleSheet() + f'''
                             QPushButton:hover 
                             {{ 
                             background-color: #EE0000; 
                             color: #ffffff;
                             }}
                             QPushButton:pressed
                             {{
                             background-color: #CC0000;
                             }}
                             '''

        self._closeBtn.setStyleSheet(close_button_style)

    def event(self, e):
        if e.type() == 100:
            self.__styleInit()
        return super().event(e)

    def eventFilter(self, obj, e):
        if e.type() == 105:
            if self.__window.isMaximized():
                self._maximizeBtn.setText('🗗')
            else:
                self._maximizeBtn.setText('🗖')
        return super().eventFilter(obj, e)

==> pyqt-windows-buttons-widget-0.0.18.tar.gz: pyqt-windows-buttons-widget-0.0.18/pyqt_windows_buttons_widget/windowsButtonsWidget.py <==
from PyQt5.QtWidgets import QWidget
from pyqt_titlebar_buttons_widget import TitlebarButtonsWidget


class WindowsButtonsWidget(TitlebarButtonsWidget):
    def __init__(self, base_widget: QWidget, hint: list = ['min', 'max', 'close']):
        super().__init__(base_widget, hint)
        self.__initUi()

    def __initUi(self):
        self._minimizeBtn.setText('🗕')
        self._maximizeBtn.setText('🗖')
        self._closeBtn.setText('🗙')

        self.__window = self._base_widget.window()
        self.__window.installEventFilter(self)

    def _styleInit(self):
        super()._styleInit()
        minimize_button_style = self._minimizeBtn.styleSheet() + 'QPushButton { border-radius: 0 }'
        maximize_button_style = self._maximizeBtn.styleSheet() + 'QPushButton { border-radius: 0 }'
        close_button_style = self._closeBtn.styleSheet() + 'QPushButton { border-radius: 0 }' + \
                             '''
                             QPushButton:hover
                             {
                             background-color: #EE0000; 
                             color: #ffffff;
                             }
                             QPushButton:pressed
                             {
                             background-color: #CC0000;
                             }
                             '''

        self._minimizeBtn.setStyleSheet(minimize_button_style)
        self._maximizeBtn.setStyleSheet(maximize_button_style)
        self._closeBtn.setStyleSheet(close_button_style)

    def eventFilter(self, obj, e):
        if e.type() == 105:
            if self.__window.isMaximized():
                self._maximizeBtn.setText('🗗')
            else:
                self._maximizeBtn.setText('🗖')
        return super().eventFilter(obj, e)
